@@ -18,10 +18,13 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#include <kcmdlineargs.h>
-#include <kaboutdata.h>
-#include <klocale.h>
-#include <kuniqueapplication.h>
+#include <QApplication>
+#include <QCommandLineParser>
+#include <QCommandLineOption>
+#include <QDir>
+
+#include <KAboutData>
+#include <KLocalizedString>
 
 #include "kmouth.h"
 #include "version.h"
@@ -34,19 +37,33 @@ static const char description[] =
 int main(int argc, char *argv[])
 {
 
-    KAboutData aboutData("kmouth", 0, ki18n("KMouth"),
-                         KMOUTH_VERSION, ki18n(description), KAboutData::License_GPL,
-                         ki18n("(c) 2002/2003, Gunnar Schmi Dt"), KLocalizedString(), "https://www.kde.org/applications/utilities/kmouth/", "kmouth@schmi-dt.de");
-    aboutData.addAuthor(ki18n("Gunnar Schmi Dt"), ki18n("Original Author"), "kmouth@schmi-dt.de");
-    aboutData.addAuthor(ki18n("Jeremy Whiting"), ki18n("Current Maintainer"), "jpwhiting@kde.org");
-    KCmdLineArgs::init(argc, argv, &aboutData);
+    QApplication app(argc, argv);
+    KLocalizedString::setApplicationDomain("kmouth");
+    QApplication::setApplicationDisplayName(i18n("KMouth"));
 
-    KCmdLineOptions options;
-    options.add("+[File]", ki18n("History file to open"));
-    KCmdLineArgs::addCmdLineOptions(options);   // Add our own options.
+    KAboutData aboutData(I18N_NOOP("kmouth"),
+                         i18n("KMouth"),
+                         KMOUTH_VERSION,
+                         i18n(description),
+                         KAboutLicense::GPL,
+                         i18n("(c) 2002/2003, Gunnar Schmi Dt"),
+                         QString(),
+                         I18N_NOOP("https://www.kde.org/applications/utilities/kmouth/"),
+                         I18N_NOOP("kmouth@schmi-dt.de"));
+    aboutData.addAuthor(i18n("Gunnar Schmi Dt"), i18n("Original Author"), QStringLiteral("kmouth@schmi-dt.de"));
+    aboutData.addAuthor(i18n("Jeremy Whiting"), i18n("Current Maintainer"), "jpwhiting@kde.org");
+    aboutData.addCredit(i18n("Olaf Schmidt"), i18n("Tips, extended phrase books"));
+
+    aboutData.setOrganizationDomain(QByteArray("kde.org"));
+    QCommandLineParser parser;
+    KAboutData::setApplicationData(aboutData);
+    parser.addVersionOption();
+    parser.addHelpOption();
+    parser.addPositionalArgument(QStringLiteral("[File]"), i18n("History file to open"));
+    aboutData.setupCommandLine(&parser);
+    parser.process(app);
+    aboutData.processCommandLine(&parser);
 
-    aboutData.addCredit(ki18n("Olaf Schmidt"), ki18n("Tips, extended phrase books"));
-    KApplication app;
 
     if (app.isSessionRestored()) {
         RESTORE(KMouthApp);
@@ -57,12 +74,12 @@ int main(int argc, char *argv[])
 
         kmouth->show();
 
-        KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
-        if (args->count()) {
-            kmouth->openDocumentFile(args->url(0));
+        if (!parser.positionalArguments().isEmpty()) {
+            const QUrl url = QUrl::fromUserInput(parser.positionalArguments().at(0), QDir::currentPath());
+            kmouth->openDocumentFile(url);
         }
-        args->clear();
+
     }
     return app.exec();
 }
