@@ -19,26 +19,23 @@
  ***************************************************************************/
 
 #include "optionsdialog.h"
-#include "wordcompletion/wordcompletionwidget.h"
 
-#include "texttospeechconfigurationwidget.h"
+#include <QDialog>
+#include <QDialogButtonBox>
+#include <QIcon>
+#include <QLabel>
+#include <QPushButton>
+#include <QTabWidget>
+#include <QVBoxLayout>
+
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KPageWidgetModel>
+#include <KSharedConfig>
+
 #include "speech.h"
-
-#include <QtGui/QLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QPixmap>
-#include <QtCore/QFile>
-
-#include <kcombobox.h>
-#include <ktabwidget.h>
-#include <klocale.h>
-#include <kconfig.h>
-#include <kglobal.h>
-#include <kcmodule.h>
-#include <klibloader.h>
-#include <kicon.h>
-#include <kpagewidgetmodel.h>
-#include <kparts/componentfactory.h>
+#include "texttospeechconfigurationwidget.h"
+#include "wordcompletion/wordcompletionwidget.h"
 
 PreferencesWidget::PreferencesWidget(QWidget *parent, const char *name)
     : QWidget(parent)
@@ -71,9 +68,9 @@ void PreferencesWidget::ok()
     save  = closeCombo->currentIndex();
 }
 
-void PreferencesWidget::readOptions(KConfig *config)
+void PreferencesWidget::readOptions()
 {
-    KConfigGroup cg(config, "Preferences");
+    KConfigGroup cg(KSharedConfig::openConfig(), "Preferences");
     if (cg.hasKey("AutomaticSpeak"))
         if (cg.readEntry("AutomaticSpeak") == QLatin1String("Yes"))
             speak = true;
@@ -82,7 +79,7 @@ void PreferencesWidget::readOptions(KConfig *config)
     else
         speak = false;
 
-    KConfigGroup cg2(config , "Notification Messages");
+    KConfigGroup cg2(KSharedConfig::openConfig() , "Notification Messages");
     if (cg2.hasKey("AutomaticSave"))
         if (cg2.readEntry("AutomaticSave") == QLatin1String("Yes"))
             save = 0;
@@ -98,15 +95,15 @@ void PreferencesWidget::readOptions(KConfig *config)
     closeCombo->setCurrentIndex(save);
 }
 
-void PreferencesWidget::saveOptions(KConfig *config)
+void PreferencesWidget::saveOptions()
 {
-    KConfigGroup cg(config, "Preferences");
+    KConfigGroup cg(KSharedConfig::openConfig(), "Preferences");
     if (speak)
         cg.writeEntry("AutomaticSpeak", "Yes");
     else
         cg.writeEntry("AutomaticSpeak", "No");
 
-    KConfigGroup cg2(config, "Notification Messages");
+    KConfigGroup cg2(KSharedConfig::openConfig(), "Notification Messages");
     if (save == 0)
         cg2.writeEntry("AutomaticSave", "Yes");
     else if (save == 1)
@@ -125,87 +122,80 @@ bool PreferencesWidget::isSpeakImmediately()
 OptionsDialog::OptionsDialog(QWidget *parent)
     : KPageDialog(parent)
 {
-    setCaption(i18n("Configuration"));
-    setButtons(KDialog::Ok | KDialog::Apply | KDialog::Cancel | KDialog::Help);
+    setWindowTitle(i18n("Configuration"));
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel|QDialogButtonBox::Help|QDialogButtonBox::Apply);
+    QWidget *mainWidget = new QWidget(this);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
+    mainLayout->addWidget(mainWidget);
+    QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
+    //PORTING SCRIPT: WARNING mainLayout->addWidget(buttonBox) must be last item in layout. Please move it.
+    mainLayout->addWidget(buttonBox);
     setFaceType(KPageDialog::List);
-    setHelp(QLatin1String("config-dialog"));
+    //setHelp(QLatin1String("config-dialog"));
 
 
     //addGridPage (1, Qt::Horizontal, i18n("General Options"), QString(), iconGeneral);
 
-    tabCtl = new KTabWidget();
-    tabCtl->setObjectName(QLatin1String("general"));
+    tabCtl = new QTabWidget();
+    tabCtl->setObjectName(QStringLiteral("general"));
 
     behaviourWidget = new PreferencesWidget(tabCtl, "prefPage");
-    behaviourWidget->layout()->setMargin(KDialog::marginHint());
     tabCtl->addTab(behaviourWidget, i18n("&Preferences"));
 
     commandWidget = new TextToSpeechConfigurationWidget(tabCtl, "ttsTab");
-    commandWidget->layout()->setMargin(KDialog::marginHint());
     tabCtl->addTab(commandWidget, i18n("&Text-to-Speech"));
 
     KPageWidgetItem *pageGeneral = new KPageWidgetItem(tabCtl, i18n("General Options"));
     pageGeneral->setHeader(i18n("General Options"));
-    pageGeneral->setIcon(KIcon(QLatin1String("configure")));
+    pageGeneral->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
     addPage(pageGeneral);
 
     completionWidget = new WordCompletionWidget(0, "Word Completion widget");
     KPageWidgetItem *pageCompletion = new KPageWidgetItem(completionWidget, i18n("Word Completion"));
     pageCompletion->setHeader(i18n("Word Completion"));
-    pageCompletion->setIcon(KIcon(QLatin1String("keyboard")));
+    pageCompletion->setIcon(QIcon::fromTheme(QStringLiteral("keyboard")));
     addPage(pageCompletion);
 
-    kttsd = loadKttsd();
-    if (kttsd != 0) {
-        KPageWidgetItem *pageKttsd = new KPageWidgetItem(kttsd, i18n("Jovie Speech Service"));
-        pageKttsd->setIcon(KIcon(QLatin1String("multimedia")));
-        pageKttsd->setHeader(i18n("KDE Text-to-Speech Daemon Configuration"));
-        addPage(pageKttsd);
-    }
+    buttonBox->button(QDialogButtonBox::Cancel)->setDefault(true);
 
-    setDefaultButton(KDialog::Cancel);
-
-    connect(this, SIGNAL(okClicked()), this, SLOT(slotOk()));
-    connect(this, SIGNAL(cancelClicked()), this, SLOT(slotCancel()));
-    connect(this, SIGNAL(applyClicked()), this, SLOT(slotApply()));
+    connect(okButton, &QAbstractButton::clicked, this, &OptionsDialog::slotOk);
+    connect(buttonBox->button(QDialogButtonBox::Cancel), &QAbstractButton::clicked, this, &OptionsDialog::slotCancel);
+    connect(buttonBox->button(QDialogButtonBox::Apply), &QAbstractButton::clicked, this, &OptionsDialog::slotApply);
 }
 
 OptionsDialog::~OptionsDialog()
 {
-    unloadKttsd();
 }
 
 void OptionsDialog::slotCancel()
 {
-//   KDialog::slotCancel();
+//   QDialog::slotCancel();
     commandWidget->cancel();
     behaviourWidget->cancel();
     completionWidget->load();
-    if (kttsd != 0)
-        kttsd->load();
 }
 
 void OptionsDialog::slotOk()
 {
-//   KDialog::slotOk();
+//   QDialog::slotOk();
     commandWidget->ok();
     behaviourWidget->ok();
     completionWidget->save();
     emit configurationChanged();
-    if (kttsd != 0)
-        kttsd->save();
-
 }
 
 void OptionsDialog::slotApply()
 {
-//   KDialog::slotApply();
+//   QDialog::slotApply();
     commandWidget->ok();
     behaviourWidget->ok();
     completionWidget->save();
     emit configurationChanged();
-    if (kttsd != 0)
-        kttsd->save();
 }
 
 TextToSpeechSystem *OptionsDialog::getTTSSystem() const
@@ -213,17 +203,17 @@ TextToSpeechSystem *OptionsDialog::getTTSSystem() const
     return commandWidget->getTTSSystem();
 }
 
-void OptionsDialog::readOptions(KConfig *config)
+void OptionsDialog::readOptions()
 {
-    commandWidget->readOptions(config, QLatin1String("TTS System"));
-    behaviourWidget->readOptions(config);
+    commandWidget->readOptions(QStringLiteral("TTS System"));
+    behaviourWidget->readOptions();
 }
 
-void OptionsDialog::saveOptions(KConfig *config)
+void OptionsDialog::saveOptions()
 {
-    commandWidget->saveOptions(config, QLatin1String("TTS System"));
-    behaviourWidget->saveOptions(config);
-    config->sync();
+    commandWidget->saveOptions(QStringLiteral("TTS System"));
+    behaviourWidget->saveOptions();
+    KSharedConfig::openConfig()->sync();
 }
 
 bool OptionsDialog::isSpeakImmediately()
@@ -231,42 +221,4 @@ bool OptionsDialog::isSpeakImmediately()
     return behaviourWidget->isSpeakImmediately();
 }
 
-KCModule *OptionsDialog::loadKttsd()
-{
-    KLibLoader *loader = KLibLoader::self();
-
-    QString libname = QLatin1String("kcm_kttsd");
-    KLibrary *lib = loader->library(QLatin1String(QFile::encodeName(libname)));
-
-    if (lib == 0) {
-        libname = QLatin1String("libkcm_kttsd");
-        lib = loader->library(QLatin1String(QFile::encodeName(QLatin1String("libkcm_kttsd"))));
-    }
-
-    if (lib != 0) {
-        QString initSym(QLatin1String("init_"));
-        initSym += libname;
-
-        if (lib->resolveFunction(QFile::encodeName(initSym))) {
-            // Reuse "lib" instead of letting createInstanceFromLibrary recreate it
-            KLibFactory *factory = lib->factory();
-            if (factory != 0) {
-                KCModule *module = factory->create<KCModule> (factory);
-                if (module)
-                    return module;
-            }
-        }
-
-        lib->unload();
-    }
-    return 0;
-}
-
-void OptionsDialog::unloadKttsd()
-{
-    KLibLoader *loader = KLibLoader::self();
-    loader->unloadLibrary(QLatin1String(QFile::encodeName(QLatin1String("libkcm_kttsd"))));
-    loader->unloadLibrary(QLatin1String(QFile::encodeName(QLatin1String("kcm_kttsd"))));
-}
-
 #include "optionsdialog.moc"
