@@ -21,18 +21,18 @@
 #ifndef PHRASEBOOK_H
 #define PHRASEBOOK_H
 
-#include <QtCore/QObject>
-#include <QtCore/QTextStream>
-#include <QtGui/QMenu>
-#include <QtGui/QPrinter>
-#include <QtXml/QXmlInputSource>
+#include <QObject>
+#include <QMenu>
+#include <QPrinter>
+#include <QTextStream>
+#include <QXmlInputSource>
 
-#include <ktoolbar.h>
-#include <kaction.h>
-#include <kactioncollection.h>
-#include <kicon.h>
+#include <QAction>
+#include <KActionCollection>
+#include <QIcon>
+#include <KToolBar>
 
-class KUrl;
+class QUrl;
 
 struct StandardBook {
     QString name;
@@ -110,7 +110,7 @@ public:
     ~PhraseBook() {}
 
     /** opens a file containing a phrase book. Returns true if successful. */
-    bool open(const KUrl &url);
+    bool open(const QUrl &url);
 
     /** decodes a phrase book. Returns true if successful. */
     bool decode(const QString &xml);
@@ -119,10 +119,10 @@ public:
     bool decode(QXmlInputSource &source);
 
     /** Writes the phrases to a file. Returns true if successful. */
-    bool save(const KUrl &url);
+    bool save(const QUrl &url);
 
     /** Writes the phrases to a file. Returns true if successful. */
-    bool save(const KUrl &url, bool asPhrasebook);
+    bool save(const QUrl &url, bool asPhrasebook);
 
     /** Writes the phrases to a QTextStream. */
     void save(QTextStream &stream, bool asPhrasebook);
@@ -135,7 +135,7 @@ public:
      *          0, if the user canceled the operation,
      *         -1, if there was an error when saving the file.
      */
-    int save(QWidget *parent, const QString &title, KUrl &url, bool phrasebookFirst = true);
+    int save(QWidget *parent, const QString &title, QUrl &url, bool phrasebookFirst = true);
 
     /** encodes the phrase book. Returns the encoded xml code. */
     QString encode();
@@ -164,16 +164,16 @@ private:
     static QString displayPath(QString path);
 };
 
-class PhraseAction : public KAction
+class PhraseAction : public QAction
 {
     Q_OBJECT
 public:
     PhraseAction(const QString& phrase, const QString& cut, const QObject* receiver, const char* slot, KActionCollection* parent)
-        : KAction(KIcon(QLatin1String("phrase")), phrase, parent)
+        : QAction(QIcon::fromTheme(QStringLiteral("phrase")), phrase, parent)
     {
         this->setShortcut(cut);
         this->phrase = phrase;
-        connect(this, SIGNAL(triggered()), this, SLOT(slotTriggered()));
+        connect(this, &QAction::triggered, this, &PhraseAction::slotTriggered);
         connect(this, SIGNAL(slotActivated(const QString &)), receiver, slot);
         parent->addAction(phrase, this);
     }
