@@ -20,36 +20,32 @@
 
 // application specific includes
 #include "phraselist.h"
+
+// include files for Qt
+#include <QApplication>
+#include <QClipboard>
+#include <QFileDialog>
+#include <QHBoxLayout>
+#include <QKeyEvent>
+#include <QListView>
+#include <QPushButton>
+#include <QStandardItem>
+#include <QVBoxLayout>
+
+// include files for KDE
+#include <KComboBox>
+#include <KConfigGroup>
+#include <QIcon>
+#include <KLineEdit>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KXMLGUIFactory>
+
 #include "kmouth.h"
 #include "texttospeechsystem.h"
 #include "phrasebook/phrasebook.h"
 #include "wordcompletion/wordcompletion.h"
 
-// include files for Qt
-#include <QtGui/QPainter>
-#include <QtGui/QLayout>
-#include <QtGui/QApplication>
-#include <QtGui/QMenu>
-#include <QtGui/QClipboard>
-#include <QtGui/QVBoxLayout>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QKeyEvent>
-#include <QStandardItem>
-#include <QListView>
-
-// include files for KDE
-#include <klineedit.h>
-#include <kcursor.h>
-#include <kiconloader.h>
-#include <klocale.h>
-#include <kfiledialog.h>
-#include <kcombobox.h>
-#include <kmessagebox.h>
-#include <kxmlguifactory.h>
-
-#include <stdlib.h>
-
-
 PhraseList::PhraseList(QWidget *parent, const char *name) : QWidget(parent)
 {
     Q_UNUSED(name);
@@ -85,7 +81,7 @@ PhraseList::PhraseList(QWidget *parent, const char *name) : QWidget(parent)
     rowLayout->addWidget(lineEdit);
     lineEdit->setFocus();
 
-    QIcon icon = KIcon(QLatin1String("text-speak"));
+    QIcon icon = QIcon::fromTheme(QStringLiteral("text-speak"));
     speakButton = new QPushButton(icon, i18n("&Speak"), this);
     speakButton->setFocusPolicy(Qt::NoFocus);
     speakButton->setAutoDefault(false);
@@ -93,12 +89,12 @@ PhraseList::PhraseList(QWidget *parent, const char *name) : QWidget(parent)
     rowLayout->addWidget(speakButton);
 
     connect(dictionaryCombo, SIGNAL(activated(QString)), completion, SLOT(setWordList(QString)));
-    connect(completion, SIGNAL(wordListsChanged(QStringList)), this, SLOT(configureCompletionCombo(QStringList)));
-    connect(m_listView->selectionModel(),  SIGNAL(selectionChanged(QItemSelection, QItemSelection)), SLOT(selectionChanged()));
-    connect(m_listView,  SIGNAL(customContextMenuRequested(QPoint)), SLOT(contextMenuRequested(QPoint)));
+    connect(completion, &WordCompletion::wordListsChanged, this, &PhraseList::configureCompletionCombo);
+    connect(m_listView->selectionModel(),  &QItemSelectionModel::selectionChanged, this, &PhraseList::selectionChanged);
+    connect(m_listView,  &QWidget::customContextMenuRequested, this, &PhraseList::contextMenuRequested);
     connect(lineEdit, SIGNAL(returnPressed(QString)), SLOT(lineEntered(QString)));
-    connect(lineEdit, SIGNAL(textChanged(QString)), SLOT(textChanged(QString)));
-    connect(speakButton, SIGNAL(clicked()), SLOT(speak()));
+    connect(lineEdit, &QLineEdit::textChanged, this, &PhraseList::textChanged);
+    connect(speakButton, &QAbstractButton::clicked, this, &PhraseList::speak);
 }
 
 PhraseList::~PhraseList()
@@ -195,26 +191,26 @@ void PhraseList::configureCompletionCombo(const QStringList &list)
     }
 }
 
-void PhraseList::saveCompletionOptions(KConfig *config)
+void PhraseList::saveCompletionOptions()
 {
-    KConfigGroup cg(config, "General Options");
+    KConfigGroup cg(KSharedConfig::openConfig(), "General Options");
     cg.writeEntry("Show speak button", speakButton->isVisible() || !lineEdit->isVisible());
 
-    KConfigGroup cg2(config, "Completion");
+    KConfigGroup cg2(KSharedConfig::openConfig(), "Completion");
     cg2.writeEntry("Mode", static_cast<int>(lineEdit->completionMode()));
     cg2.writeEntry("List", completion->currentWordList());
 }
 
-void PhraseList::readCompletionOptions(KConfig *config)
+void PhraseList::readCompletionOptions()
 {
-    KConfigGroup cg(config, "General Options");
+    KConfigGroup cg(KSharedConfig::openConfig(), "General Options");
     if (!cg.readEntry("Show speak button", true))
         speakButton->hide();
 
-    if (config->hasGroup("Completion")) {
-        KConfigGroup cg2(config, "Completion");
-        int mode = cg2.readEntry("Mode", int(KGlobalSettings::completionMode()));
-        lineEdit->setCompletionMode(static_cast<KGlobalSettings::Completion>(mode));
+    if (KSharedConfig::openConfig()->hasGroup("Completion")) {
+        KConfigGroup cg2(KSharedConfig::openConfig(), "Completion");
+        //int mode = cg2.readEntry("Mode", int(KGlobalSettings::completionMode()));
+        //lineEdit->setCompletionMode(static_cast<KGlobalSettings::Completion>(mode));
 
         QString current = cg2.readEntry("List", QString());
         const QStringList list = completion->wordLists();
@@ -284,7 +280,7 @@ void PhraseList::insert(const QString &s)
 
 void PhraseList::speakListSelection()
 {
-    speakPhrase(getListSelection().join(QLatin1String("\n")));
+    speakPhrase(getListSelection().join(QStringLiteral("\n")));
 }
 
 void PhraseList::removeListSelection()
@@ -309,7 +305,7 @@ void PhraseList::cutListSelection()
 
 void PhraseList::copyListSelection()
 {
-    QApplication::clipboard()->setText(getListSelection().join(QLatin1String("\n")));
+    QApplication::clipboard()->setText(getListSelection().join(QStringLiteral("\n")));
 }
 
 void PhraseList::lineEntered(const QString &phrase)
@@ -324,7 +320,6 @@ void PhraseList::lineEntered(const QString &phrase)
 
 void PhraseList::speakPhrase(const QString &phrase)
 {
-    // QApplication::setOverrideCursor (KCursor::WaitCursor, false);
     QApplication::setOverrideCursor(Qt::WaitCursor);
     KMouthApp *theApp = (KMouthApp *) parentWidget();
     QString language = completion->languageOfWordList(completion->currentWordList());
@@ -353,9 +348,9 @@ void PhraseList::contextMenuRequested(const QPoint &pos)
 {
     QString name;
     if (existListSelection())
-        name = QLatin1String("phraselist_selection_popup");
+        name = QStringLiteral("phraselist_selection_popup");
     else
-        name = QLatin1String("phraselist_popup");
+        name = QStringLiteral("phraselist_popup");
 
     KMouthApp *theApp = (KMouthApp *) parentWidget();
     KXMLGUIFactory *factory = theApp->factory();
@@ -475,21 +470,21 @@ void PhraseList::save()
         book += PhraseBookEntry(Phrase(item->text()));
     }
 
-    KUrl url;
+    QUrl url;
     if (book.save(this, i18n("Save As"), url, false) == -1)
         KMessageBox::sorry(this, i18n("There was an error saving file\n%1", url.url()));
 }
 
 void PhraseList::open()
 {
-    KUrl url = KFileDialog::getOpenUrl(KUrl(),
-                                       i18n("*|All Files\n*.phrasebook|Phrase Books (*.phrasebook)\n*.txt|Plain Text Files (*.txt)"), this, i18n("Open File as History"));
+    QUrl url = QFileDialog::getOpenFileUrl(this, i18n("Open File as History"), QUrl(),
+                                           i18n("All Files (*);;Phrase Books (*.phrasebook);;Plain Text Files (*.txt)"));
 
     if (!url.isEmpty())
         open(url);
 }
 
-void PhraseList::open(KUrl url)
+void PhraseList::open(const QUrl &url)
 {
     // We want to open a history of spoken sentences here. However, as
     // the class PhraseBook does already provide a method for opening
@@ -504,7 +499,7 @@ void PhraseList::open(KUrl url)
         for (it = list.begin(); it != list.end(); ++it)
             insertIntoPhraseList(*it, false);
     } else
-        KMessageBox::sorry(this, i18n("There was an error loading file\n%1", url.url()));
+        KMessageBox::sorry(this, i18n("There was an error loading file\n%1", url.toDisplayString()));
 }
 
 #include "phraselist.moc"
