@@ -19,27 +19,23 @@
  ***************************************************************************/
 
 #include "wordcompletionwidget.h"
-#include "wordcompletion.h"
-#include "dictionarycreationwizard.h"
 
-#include <QtGui/QLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QCheckBox>
-#include <QtGui/QLineEdit>
+#include <QFileDialog>
 #include <QStandardItemModel>
+#include <QStandardPaths>
+#include <QUrl>
 
 #include <QDebug>
 
-#include <klineedit.h>
-#include <kurlrequester.h>
-#include <klocale.h>
-#include <kglobal.h>
-#include <kstandarddirs.h>
-#include <kconfig.h>
-#include <kfiledialog.h>
-#include <kio/netaccess.h>
-#include <kmessagebox.h>
-#include <klanguagebutton.h>
+#include <KConfigGroup>
+#include <KJobUiDelegate>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KSharedConfig>
+#include <KIO/FileCopyJob>
+
+#include "dictionarycreationwizard.h"
+#include "wordcompletion.h"
 
 WordCompletionWidget::WordCompletionWidget(QWidget *parent, const char *name)
     : QWidget(parent)
@@ -53,23 +49,19 @@ WordCompletionWidget::WordCompletionWidget(QWidget *parent, const char *name)
     languageButton->loadAllLanguages();
 
     // Connect the signals from hte KCMKTTSDWidget to this class
-    connect(addButton, SIGNAL(clicked()), this, SLOT(addDictionary()));
-    connect(deleteButton, SIGNAL(clicked()), this, SLOT(deleteDictionary()));
-    connect(moveUpButton, SIGNAL(clicked()), this, SLOT(moveUp()));
-    connect(moveDownButton, SIGNAL(clicked()), this, SLOT(moveDown()));
-    connect(exportButton, SIGNAL(clicked()), this, SLOT(exportDictionary()));
+    connect(addButton, &QAbstractButton::clicked, this, &WordCompletionWidget::addDictionary);
+    connect(deleteButton, &QAbstractButton::clicked, this, &WordCompletionWidget::deleteDictionary);
+    connect(moveUpButton, &QAbstractButton::clicked, this, &WordCompletionWidget::moveUp);
+    connect(moveDownButton, &QAbstractButton::clicked, this, &WordCompletionWidget::moveDown);
+    connect(exportButton, &QAbstractButton::clicked, this, &WordCompletionWidget::exportDictionary);
 
-    connect(dictionaryView->selectionModel(), SIGNAL(selectionChanged(QItemSelection, QItemSelection)),
-            this, SLOT(selectionChanged()));
-    connect(dictionaryName, SIGNAL(textChanged(QString)), this, SLOT(nameChanged(QString)));
-    connect(languageButton, SIGNAL(activated(QString)), this, SLOT(languageSelected()));
-
-    // Object for the KCMKTTSD configuration
-    config = new KConfig(QLatin1String("kmouthrc"));
+    connect(dictionaryView->selectionModel(), &QItemSelectionModel::selectionChanged,
+            this, &WordCompletionWidget::selectionChanged);
+    connect(dictionaryName, &QLineEdit::textChanged, this, &WordCompletionWidget::nameChanged);
+    connect(languageButton, &KLanguageButton::activated, this, &WordCompletionWidget::languageSelected);
 
     // Load the configuration from the file
     load();
-    qDebug() << "horizontal header data is " << model->headerData(0, Qt::Horizontal) << model->headerData(1, Qt::Horizontal);
 }
 
 /**
@@ -77,7 +69,6 @@ WordCompletionWidget::WordCompletionWidget(QWidget *parent, const char *name)
  */
 WordCompletionWidget::~WordCompletionWidget()
 {
-    delete config;
 }
 
 /***************************************************************************/
@@ -91,10 +82,10 @@ void WordCompletionWidget::load()
     model->setHorizontalHeaderLabels(labels);
 
     // Set the group general for the configuration of kttsd itself (no plug ins)
-    const QStringList groups = config->groupList();
+    const QStringList groups = KSharedConfig::openConfig()->groupList();
     for (QStringList::const_iterator it = groups.constBegin(); it != groups.constEnd(); ++it)
         if ((*it).startsWith(QLatin1String("Dictionary "))) {
-            KConfigGroup cg(config, *it);
+            KConfigGroup cg(KSharedConfig::openConfig(), *it);
             QString filename = cg.readEntry("Filename");
             QString languageTag = cg.readEntry("Language");
             QStandardItem *nameItem = new QStandardItem(cg.readEntry("Name"));
@@ -110,7 +101,7 @@ void WordCompletionWidget::load()
 
     // Clean up disc space
     for (QStringList::const_iterator it = newDictionaryFiles.constBegin(); it != newDictionaryFiles.constEnd(); ++it) {
-        QString filename = KGlobal::dirs()->findResource("appdata", *it);
+        QString filename = QStandardPaths::locate(QStandardPaths::DataLocation, *it);
         if (!filename.isEmpty() && !filename.isNull())
             QFile::remove(filename);
     }
@@ -119,25 +110,25 @@ void WordCompletionWidget::load()
 
 void WordCompletionWidget::save()
 {
-    const QStringList groups = config->groupList();
+    const QStringList groups = KSharedConfig::openConfig()->groupList();
     for (QStringList::const_iterator it = groups.constBegin(); it != groups.constEnd(); ++it)
         if ((*it).startsWith(QLatin1String("Dictionary ")))
-            config->deleteGroup(*it);
+            KSharedConfig::openConfig()->deleteGroup(*it);
 
     int row = 0;
     for (int row = 0; row < model->rowCount(); ++row) {
         const QStandardItem *nameItem = model->item(row, 0);
         const QStandardItem *languageItem = model->item(row, 1);
-        KConfigGroup cg(config, QString(QLatin1String("Dictionary %1")).arg(row));
+        KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("Dictionary %1").arg(row));
         cg.writeEntry("Filename", nameItem->data().toString());
         cg.writeEntry("Name",     nameItem->text());
         cg.writeEntry("Language", languageItem->text());
     }
-    config->sync();
+    KSharedConfig::openConfig()->sync();
 
     // Clean up disc space
     for (QStringList::const_iterator it = removedDictionaryFiles.constBegin(); it != removedDictionaryFiles.constEnd(); ++it) {
-        QString filename = KGlobal::dirs()->findResource("appdata", *it);
+        QString filename = QStandardPaths::locate(QStandardPaths::DataLocation, *it);
         if (!filename.isEmpty() && !filename.isNull())
             QFile::remove(filename);
     }
@@ -213,19 +204,20 @@ void WordCompletionWidget::exportDictionary()
     const QStandardItem *nameItem = model->item(dictionaryView->currentIndex().row(), 0);
 
     if (nameItem != 0) {
-        KUrl url = KFileDialog::getSaveUrl(QString(), QString(), this, i18n("Export Dictionary"));
+        QUrl url = QFileDialog::getSaveFileUrl(this, i18n("Export Dictionary"));
         if (url.isEmpty() || !url.isValid())
             return;
 
-        if (KIO::NetAccess::exists(url, KIO::NetAccess::DestinationSide, this)) {
-            if (KMessageBox::warningContinueCancel(0, QString(QLatin1String("<qt>%1</qt>")).arg(i18n("The file %1 already exists. "
+        if (url.isLocalFile() && QFile::exists(url.toLocalFile())) {
+            if (KMessageBox::warningContinueCancel(0, QStringLiteral("<qt>%1</qt>").arg(i18n("The file %1 already exists. "
                                                    "Do you want to overwrite it?", url.url())), i18n("File Exists"), KGuiItem(i18n("&Overwrite"))) == KMessageBox::Cancel) {
                 return;
             }
         }
-        KUrl src;
-        src.setPath(KGlobal::dirs()->findResource("appdata", nameItem->data().toString()));
-        KIO::NetAccess::file_copy(src, url, this);
+        QUrl src;
+        src.setPath(QStandardPaths::locate(QStandardPaths::DataLocation, nameItem->data().toString()));
+        KIO::FileCopyJob *job = KIO::file_copy(src, url);
+        job->exec();
     }
 }
 
