@@ -21,12 +21,10 @@
 #ifndef WORDLIST_H
 #define WORDLIST_H
 
-#include <QtXml/QXmlDefaultHandler>
-#include <QtXml/QXmlParseException>
-#include <QtXml/QXmlAttributes>
-#include <QtCore/QObject>
-#include <QtCore/QMap>
-#include <QtCore/QTextStream>
+#include <QMap>
+#include <QXmlAttributes>
+#include <QXmlDefaultHandler>
+#include <QXmlParseException>
 
 class QTextCodec;
 class QProgressDialog;
@@ -59,29 +57,29 @@ public:
     XMLParser();
     ~XMLParser();
 
-    bool warning(const QXmlParseException &exception);
-    bool error(const QXmlParseException &exception);
-    bool fatalError(const QXmlParseException &exception);
-    QString errorString() const;
+    bool warning(const QXmlParseException &exception) override;
+    bool error(const QXmlParseException &exception) override;
+    bool fatalError(const QXmlParseException &exception) override;
+    QString errorString() const override;
 
     /** Processes the start of the document. */
-    bool startDocument();
+    bool startDocument() override;
 
     /** Processes the start tag of an element. */
     bool startElement(const QString &, const QString &, const QString &name,
-                      const QXmlAttributes &attributes);
+                      const QXmlAttributes &attributes) override;
 
     /** Processes a chunk of normal character data. */
-    bool characters(const QString &ch);
+    bool characters(const QString &ch) override;
 
     /** Processes whitespace. */
-    bool ignorableWhitespace(const QString &ch);
+    bool ignorableWhitespace(const QString &ch) override;
 
     /** Processes the end tag of an element. */
-    bool endElement(const QString &, const QString &, const QString &name);
+    bool endElement(const QString &, const QString &, const QString &name) override;
 
     /** Processes the end of the document. */
-    bool endDocument();
+    bool endDocument() override;
 
     /** returns a list of words */
     WordMap getList();
